-- **************************************************
-- Provide Moho with the name of this script object
-- **************************************************

ScriptName = "DS_ActionButtons"

-- **************************************************
-- General information about this script
-- **************************************************

DS_ActionButtons = {}


function DS_ActionButtons:Name()
	return "Action Buttons"
end

function DS_ActionButtons:Version()
	return "0.1"
end

function DS_ActionButtons:Description()
	return "Insert actions by clicking buttons"
end

function DS_ActionButtons:Creator()
	return "dauid.com"
end

function DS_ActionButtons:UILabel()
	return "Action Buttons"
end

function DS_ActionButtons:LoadPrefs(prefs)
	DS_ActionButtons.sort = prefs:GetBool("DS_ActionButtons.sort", true)
	DS_ActionButtons.reference = prefs:GetBool("DS_ActionButtons.reference", true)
end

function DS_ActionButtons:SavePrefs(prefs)
	prefs:SetBool("DS_ActionButtons.sort", DS_ActionButtons.sort)
	prefs:SetBool("DS_ActionButtons.reference", DS_ActionButtons.reference)
end

function DS_ActionButtons:ResetPrefs()
	DS_ActionButtons.sort= true
	DS_ActionButtons.reference = false
end
-- **************************************************
-- Recurring values
-- **************************************************
DS_ActionButtons.actname = {} 
DS_ActionButtons.lastlayer = {} 
DS_ActionButtons.lastaction = "none"
DS_ActionButtons.nexttolastaction = "none"
--DS_ActionButtons.sort = true
--DS_ActionButtons.reference = false
-- **************************************************
-- The guts of this script
-- **************************************************

function DS_ActionButtons:IsEnabled(moho)
	return true
end

function DS_ActionButtons:IsRelevant(moho)
	return true
end

function DS_ActionButtons:OnMouseDown(moho, mouseEvent)
	local layer = mouseEvent.view:PickGlobalLayer(mouseEvent.pt)
	if layer ~= nil then
			--moho:SetSelLayer(layer:Parent()) 
			moho:SetSelLayer(layer) 
			moho:UpdateUI()
			
	end
end

-- **************************************************
-- Tool options - create and respond to tool's UI
-- **************************************************


DS_ActionButtons.COPY = MOHO.MSG_BASE
DS_ActionButtons.REF = MOHO.MSG_BASE +1
DS_ActionButtons.SORT = MOHO.MSG_BASE +2
DS_ActionButtons.BUTTPRESS = MOHO.MSG_BASE + 3


function DS_ActionButtons:DoLayout(moho, layout)
	self.checkBox = LM.GUI.CheckBox("Reference", self.REF)
	layout:AddChild(self.checkBox)
	
	
	self.sortBox = LM.GUI.CheckBox("Sort names", self.SORT)
	layout:AddChild(self.sortBox)
	
	self.lastname=LM.GUI.DynamicText("Last: Here is the action", 0)
	self.lastname:SetValue("Last: " .. self.nexttolastaction)
	--layout:AddChild(self.lastname)
	
	self.actname = {}
	local layer = moho.layer
	for i=0, layer:CountActions()-1 do
		if string.sub(layer:ActionName(i), 1, 6) ~= "Scene " then ---string.sub("Scene", 1,5 ) then 
			table.insert(DS_ActionButtons.actname,layer:ActionName(i))
		end
	end
	if self.sort then
	table.sort(self.actname)
	end
	for k, v in pairs(self.actname) do
			layout:AddChild(LM.GUI.Button(v, self.BUTTPRESS+k))
	end
	
	
end

function DS_ActionButtons:UpdateWidgets(moho)
	self.checkBox:SetValue(self.reference)
	self.sortBox:SetValue(self.sort)
	--if self.sortBox:Value() then
		--table.sort(self.actname)
	--end
end

function DS_ActionButtons:HandleMessage(moho, view, msg)
	if (msg == self.SORT) then
		self.sort = self.sortBox:Value()
	end
	if (msg == self.REF) then
		self.reference = self.checkBox:Value()
	end
	if (msg > self.BUTTPRESS) then
		local num = msg - self.BUTTPRESS
		local layer = moho.layer
		layer:InsertAction(self.actname[num], moho.frame, self.checkBox:Value())
		self.nexttolastaction = self.lastaction
		self.lastaction = self.actname[num]
		self.lastname:SetValue("Last: " .. self.nexttolastaction)
		layer:UpdateCurFrame(true)
	end
	
	moho.view:DrawMe()

moho:UpdateUI()
	
end
