
-- **************************************************
-- Provide Moho with the name of this script object
-- **************************************************

ScriptName = "DS_FileToMaya"

-- **************************************************
-- General information about this script
-- **************************************************

DS_FileToMaya = {}
function DS_FileToMaya:Name()
	return "DS File to Maya"
end

function DS_FileToMaya:Version()
	return "0.3"
end

function DS_FileToMaya:Description()
	return "Export camera and nodes to Maya"
end

function DS_FileToMaya:Creator()
	return "dauid.com"
end

function DS_FileToMaya:UILabel()
	return("DS File to Maya")
end
-- **************************************************
-- Recurring values
-- **************************************************

DS_FileToMaya.scale=540

--************************menu
local DS_Dialog = {}

DS_Dialog.UPDATE = MOHO.MSG_BASE

function DS_Dialog:new(moho)
	local d = LM.GUI.SimpleDialog("Settings", DS_Dialog)
	local l = d:GetLayout()

	d.moho = moho

	l:AddChild(LM.GUI.StaticText("Scale"), LM.GUI.ALIGN_LEFT)
	d.Scale = LM.GUI.TextControl(0, "0.0000", DS_Dialog.UPDATE, LM.GUI.FIELD_UFLOAT)
	l:AddChild(d.Scale)
	d.Scale:SetValue(540)
	
	return d
end


function DS_Dialog:HandleMessage(what)

end

function DS_Dialog:OnOK()
	DS_FileToMaya.scale = self.Scale:FloatValue()

end


-- **************************************************
-- The guts of this script
-- **************************************************


function DS_FileToMaya:OnMouseDown(moho, mouseEvent)
	self:Run(moho)
end

function DS_FileToMaya:Run(moho)

local dlog = DS_Dialog:new(moho)
	if (dlog:DoModal() == LM.GUI.MSG_CANCEL) then
		return
	end

local path = LM.GUI.SaveFile("Select Data File")
	if (path == "") then
		return
	end
	
		local f = io.open(path..".ma", "w")

	if (f == nil) then
		return
	end

local width = moho.document:Width()
local height = moho.document:Height()
local aspect = moho.document:AspectRatio()
local newX = (moho.document:Width()/2)
local newY = moho.document:Height()/2
local newZ = moho.document:Height()/2


local fps = moho.document:Fps()
local startframe = moho.document:StartFrame()
local endframe = moho.document:EndFrame()
local campos= LM.Vector3:new_local()
local pantilt = LM.Vector2:new_local()
local layerPos  = LM.Vector3:new_local()

f:write('//Maya ASCII 1.0 scene file\n')
f:write('requires maya "6.0";\n')
f:write("currentUnit -l meters -a degree -t pal;\n")
f:write("playbackOptions -min ".. startframe .." -max ".. endframe.. " -animationStartTime ".. startframe .." -animationEndTime ".. endframe.. ";\n")
f:write("select -ne defaultResolution;\n")
f:write('\t setAttr ".w" '.. width ..';\n')
f:write('\t setAttr ".h" '.. height ..';\n')
f:write('\t setAttr ".dar" '.. aspect ..';\n')
f:write('\t setAttr ".ldar" yes;\n')
f:write("\n")
f:write('createNode transform -n "anime_scene";\n')
f:write('\t  setAttr ".s" -type "double3" 1.0 1.0 1.0;\n')
f:write('createNode locator -n "anime_scene_shape" -p "anime_scene";\n')
f:write('\t  setAttr -k off ".v";\n')
f:write("\n")
f:write('createNode transform -n "AnimeCam" -p "anime_scene";\n')
f:write('\t  setAttr ".ro" 2;\n')
f:write('\t  setAttr ".s" -type "double3" 0.4 0.4 0.4;\n')
f:write('createNode camera -n "AnimeCam_Shape" -p "AnimeCam";\n')
f:write('\t  setAttr -k off ".v";\n')
f:write('\t  setAttr ".cap" -type "double2" 0.755906 0.425197;\n')
f:write('\t  setAttr ".ff" 0;\n')
f:write('\t  setAttr ".imn" -type "string" "AnimeCam";\n')
f:write('\t  setAttr ".den" -type "string" "AnimeCam_depth";\n')
f:write('\t   setAttr ".man" -type "string" "AnimeCam_mask";\n')
f:write("\n")

f:write('createNode animCurveTU -n "AnimeCam_focalLength";\n')
f:write('\t   setAttr -s '.. endframe-startframe ..' ".ktv['.. startframe ..':'..endframe..']" ')
for i = startframe, endframe do
	local zoom = ((moho.document.fCameraZoom:GetValue(i)*1.732)*DS_FileToMaya.scale)/100
	f:write(i .." ".. zoom.." " )
	end 
f:write(";\n")

f:write('createNode animCurveTL -n "AnimeCam_translateX";\n')
f:write('\t   setAttr -s '.. endframe-startframe ..' ".ktv['.. startframe ..':'..endframe..']" ')
for i = startframe, endframe do
	campos = moho.document.fCameraTrack:GetValue(i)*DS_FileToMaya.scale
	f:write(i .." ".. campos.x .." " )
	end 
f:write(";\n")

f:write('createNode animCurveTL -n "AnimeCam_translateY";\n')
f:write('\t   setAttr -s '.. endframe-startframe ..' ".ktv['.. startframe ..':'..endframe..']" ')
for i = startframe, endframe do
	campos = moho.document.fCameraTrack:GetValue(i)*DS_FileToMaya.scale
	f:write(i .." ".. campos.y .." " )
	end 
f:write(";\n")

f:write('createNode animCurveTL -n "AnimeCam_translateZ";\n')
f:write('\t   setAttr -s '.. endframe-startframe ..' ".ktv['.. startframe ..':'..endframe..']" ')
for i = startframe, endframe do
	campos = moho.document.fCameraTrack:GetValue(i)*DS_FileToMaya.scale
	f:write(i .." ".. campos.z .." " )
	end 
f:write(";\n")

f:write('createNode animCurveTL -n "AnimeCam_rotateX";\n')
f:write('\t   setAttr -s '.. endframe-startframe ..' ".ktv['.. startframe ..':'..endframe..']" ')
for i = startframe, endframe do
	pantilt = moho.document.fCameraPanTilt:GetValue(i)
	f:write(i .." ".. math.deg(pantilt.x) .." " )
	end 
f:write(";\n")

f:write('createNode animCurveTL -n "AnimeCam_rotateY";\n')
f:write('\t   setAttr -s '.. endframe-startframe ..' ".ktv['.. startframe ..':'..endframe..']" ')
for i = startframe, endframe do
	pantilt = moho.document.fCameraPanTilt:GetValue(i)
	f:write(i .." ".. math.deg(pantilt.y)*(-1) .." " )
	end 
f:write(";\n")

f:write('createNode animCurveTL -n "AnimeCam_rotateZ";\n')
f:write('\t   setAttr -s '.. endframe-startframe ..' ".ktv['.. startframe ..':'..endframe..']" ')
for i = startframe, endframe do
	camroll = math.deg(moho.document.fCameraRoll:GetValue(i)*(-1))
	f:write(i .." ".. camroll .." " )
	end 
f:write(";\n")

f:write('connectAttr "AnimeCam_translateX.o" "AnimeCam.tx";\n')
f:write('connectAttr "AnimeCam_translateY.o" "AnimeCam.ty";\n')
f:write('connectAttr "AnimeCam_translateZ.o" "AnimeCam.tz";\n')
f:write('connectAttr "AnimeCam_rotateX.o" "AnimeCam.rx";\n')
f:write('connectAttr "AnimeCam_rotateY.o" "AnimeCam.ry";\n')
f:write('connectAttr "AnimeCam_rotateZ.o" "AnimeCam.rz";\n')
f:write('connectAttr "AnimeCam_rotateZ.o" "AnimeCam.rz";\n')
f:write('connectAttr "AnimeCam_focalLength.o" "AnimeCam_Shape.fl";\n')
f:write("\n")
f:write('createNode script -n "animationScriptNode";\n')
f:write('\t  setAttr ".a" -type "string" (\n')
f:write('"playbackOptions -min '.. startframe ..' -max '.. endframe ..' -animationStartTime '.. startframe ..' -animationEndTime '.. endframe ..' -fps '.. fps ..';");(\n')
f:write('select -ne :time1;\n')
f:write('\t  setAttr ".o" 0;\n')
f:write("\n")
----------------------------------------------

local numlayers = moho.document:CountLayers() --Get number of layers
for top = 0, numlayers - 1 do
local layer=moho.document:Layer(top)
layerName=layer:Name()
translation = layer.fTranslation:GetValue(0)
anchor = layer:Origin()
layerPos.x = translation.x + anchor.x
layerPos.y = translation.y + anchor.y
layerPos.z = translation.z

f:write('createNode transform -n "'.. layerName ..'" -p "anime_scene";\n')
f:write('\t  setAttr ".t" -type "double3" '.. layerPos.x*DS_FileToMaya.scale ..' '.. layerPos.y*DS_FileToMaya.scale ..' '.. layerPos.z*DS_FileToMaya.scale ..';\n')
f:write('\t  setAttr ".s" -type "double3" 0.05 0.05 0.05;\n')
f:write('createNode locator -n "'.. layerName ..'" -p "'.. layerName ..'";\n')
f:write('\t  setAttr -k off ".v";\n')
end
----------------------------------------------
f:close() --Close the file
LM.GUI.Alert(LM.GUI.ALERT_INFO, "Saved to " ..path..".ma", nil, nil, "OK", nil, nil)
end